# SerpapiApp MCP Server

An MCP Server for the SerpapiApp API.

## 🛠️ Tool List

This is automatically generated from OpenAPI schema for the SerpapiApp API.


| Tool | Description |
|------|-------------|
| `search` | Performs a search using the SerpApi service and returns formatted search results. |
| `google_maps_search` | Performs a Google Maps search using the SerpApi service and returns formatted search results. |
| `get_google_maps_reviews` | Retrieves Google Maps reviews for a specific place using the SerpApi service. |
